Module error

Module error 

This module contains the error handling logic and types for the h3 crate.

Structs

Code
An HTTP/3 “application error code”.

Enums

ConnectionError
This enum represents the closure of a connection because of an a closed quic connection This can be either from this endpoint because of a violation of the protocol or from the remote endpoint
LocalError
This enum represents a local error
StreamError
This enum represents a stream error