StreamErrorIncoming

Enum StreamErrorIncoming 

pub enum StreamErrorIncoming {
    ConnectionErrorIncoming {
        connection_error: ConnectionErrorIncoming,
    },
    StreamTerminated {
        error_code: u64,
    },
    Unknown(Box<dyn Error + Send + Sync>),
}
Error type to communicate that the stream was closed

This is used by to implement the quic abstraction traits When an error within the quic trait implementation occurs, use ConnectionErrorIncoming variant with InternalError

Variants



ConnectionErrorIncoming

Stream is closed because the whole connection is closed

Fields

connection_error: ConnectionErrorIncoming

Connection error



StreamTerminated

Stream side was closed by the peer

This can mean a reset for peers sending side or a stop_sending for peers receiving side

Fields

error_code: u64

Error code sent by the peer



Unknown(Box<dyn Error + Send + Sync>)

A unknown error occurred (not relevant to h3)

H3 will handle this exactly like a StreamTerminated like closing the connection with an error if http3 forbids a stream end for example with the control stream