RequestResolver

Struct RequestResolver 

pub struct RequestResolver<C, B>
where C: Connection<B>, C::BidiStream: SendStream<B>, B: Buf,
{ /* private fields */ }
Helper struct to await the request headers and return a Request object

Implementations

Source

impl<C, B> RequestResolver<C, B>
where C: Connection<B>, B: Buf,

pub async fn resolve_request( self, ) -> Result<(Request<()>, RequestStream<C::BidiStream, B>), StreamError>

Returns a future to await the request headers and return a Request object

pub fn accept_with_frame( self, frame: Result<Option<Frame<PayloadLen>>, FrameStreamError>, ) -> Result<ResolvedRequest<C, B>, StreamError>

Accepts a http request where the first frame has already been read and decoded.

This is needed as a bidirectional stream may be read as part of incoming webtransport bi-streams. If it turns out that the stream is not a WEBTRANSPORT_STREAM the request may still want to be handled and passed to the user.