#[non_exhaustive]pub enum ConnectionError {
#[non_exhaustive] Local {
error: LocalError,
},
#[non_exhaustive] Remote(ConnectionErrorIncoming),
#[non_exhaustive] Timeout,
}Expand description
This enum represents the closure of a connection because of an a closed quic connection This can be either from this endpoint because of a violation of the protocol or from the remote endpoint
When the code Code::H3_NO_ERROR is used bei this peer or the remote peer, the connection is closed without an error according to the h3 spec
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
#[non_exhaustive]Local
The error occurred on the local side of the connection
Fields
This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.

error: LocalErrorThe error
#[non_exhaustive]Remote(ConnectionErrorIncoming)
Error returned by the quic layer I might be an quic error or the remote h3 connection closed the connection with an error
#[non_exhaustive]Timeout
Timeout occurred
Implementations
Sourceimpl ConnectionError
impl ConnectionError
Sourcepub fn is_h3_no_error(&self) -> bool
pub fn is_h3_no_error(&self) -> bool
Returns if the error is H3_NO_ERROR local or remote